.. tomo documentation master file, created by
   sphinx-quickstart on Tue Jan 14 09:27:17 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to tomo's documentation!
================================

Contents
========
The Longitudinal Beam Tomography code tomo is a CERN software package for the
reconstruction of the phase space density of a particle bunch.


Modules
=======

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   modules/data.rst
   modules/tracking.rst
   modules/tomography.rst
   modules/utils.rst
   modules/cpp_routines.rst
   modules/compat.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
